@@ -108,11 +108,28 @@ typedef struct {
 } DialogData;
 
 
+static gboolean
+change_max_size (gpointer user_data)
+{
+	DialogData *data = user_data;
+
+	g_source_remove (data->timeout);
+	data->timeout = 0;
+
+	quick_lounge_set_max_size (data->quick_lounge, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->p_maxsize_spinbutton)));
+
+	return FALSE;
+}
+
+
 /* called when the main dialog is closed. */
 static void
 destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
+	if (data->timeout != 0) 
+		change_max_size (data);
+
 	g_object_unref (data->gui);
 	g_free (data);
 }
@@ -661,20 +678,6 @@ min_size_value_changed_cb (GtkWidget  *widget,
 }
 
 
-static gboolean
-change_max_size (gpointer user_data)
-{
-	DialogData *data = user_data;
-
-	g_source_remove (data->timeout);
-	data->timeout = 0;
-
-	quick_lounge_set_max_size (data->quick_lounge, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->p_maxsize_spinbutton)));
-
-	return FALSE;
-}
-
-
 static void
 max_size_value_changed_cb (GtkWidget  *widget,
 			   DialogData *data)
@@ -802,10 +805,9 @@ drag_data_received  (GtkWidget          *widget,
 			if (! is_desktop_file (src_uri))
 				continue;
 
-			uri = g_strconcat (quick_lounge->location,
-					   "/",
-					   file_name_from_path (src_uri),
-					   NULL);
+			uri = g_build_filename (quick_lounge->location,
+						file_name_from_path (src_uri),
+						NULL);
 			
 			if (strcmp (src_uri, uri) == 0) {
 				button = get_button_from_uri (quick_box, uri);
